@@ -11,6 +11,8 @@ OC.L10N.register(
     "Share with users or groups" : "Mit Benutzern oder Gruppen teilen",
     "can edit" : "kann bearbeiten",
     "Close" : "Schließen",
+    "Enabled" : "Aktiviert",
+    "Disabled" : "Deaktiviert",
     "Copied!" : "Kopiert!",
     "Not supported!" : "Nicht unterstützt!",
     "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
@@ -28,9 +30,10 @@ OC.L10N.register(
     "Save changes" : "Änderungen speichern",
     "Address book" : "Adressbuch",
     "Loading contacts …" : "Kontakte laden…",
-    "Import into" : "importieren nach",
-    "Importing..." : "Importiere...",
+    "Import into" : "Importieren nach",
+    "Importing..." : "Importiere…",
     "Select your addressbook" : "Wähle Dein Adressbuch",
+    "Import is disabled because no writable address book had been found." : "Der Import wurde deaktiviert, denn es wurde kein beschreibbares Adressbuch gefunden.",
     "No search result for {query}" : "Keine Suchergebnisse zu {query}",
     "All contacts" : "Alle Kontakte",
     "Post office box" : "Postfach",
@@ -49,14 +52,17 @@ OC.L10N.register(
     "New contact" : "Neuer Kontakt",
     "Not grouped" : "Nicht gruppiert",
     "Sort by" : "Sortiere nach",
+    "There is no address book available to create a contact." : "Es ist kein Adressbuch vorhanden um den Kontakt zu erstellen.",
     "{addressbook} shared by {owner}" : "{addressbook} geteilt von {owner}",
     "Contact not found." : "Kontakt nicht gefunden.",
-    "You don't have permission to write to this addressbook." : "Du hast nicht die erforderliche Berechtigung um Einträge in diesem Adressbuch vorzunehmen",
+    "You don't have permission to write to this addressbook." : "Du hast nicht die Berechtigung um Einträge in diesem Adressbuch vorzunehmen",
     "Contact could not be created." : "Kontakt konnte nicht erstellt werden.",
     "No contacts in file. Only vCard files are allowed." : "Keine Adressen in der Datei. Es kann nur das vCard-Format verarbeitet werden.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Es werden nur vCard-Format 4.0 (RFC6350) oder 3.0 (RFC2426) unterstützt.",
+    "Contact could not be moved." : "Kontakt konnte nicht verschoben werden.",
     "Contact could not be saved." : "Kontakt konnte nicht gespeichert werden.",
-    "Waiting for the server to be ready..." : "Warte darauf dass der Server bereit ist...",
+    "Waiting for the server to be ready…" : "Warte bis der Server bereit ist…",
+    "Importing…" : "Importiere…",
     "Display name" : "Anzeigename",
     "Nickname" : "Spitzname",
     "Detailed name" : "Detaillierter Name",
@@ -64,7 +70,7 @@ OC.L10N.register(
     "Website" : "Internetseite",
     "Federated Cloud ID" : "Federated-Cloud-ID",
     "Home" : "Privat",
-    "Work" : "Geschäftlich",
+    "Work" : "Arbeit",
     "Other" : "Andere",
     "Groups" : "Gruppen",
     "Birthday" : "Geburtstag",
@@ -74,14 +80,17 @@ OC.L10N.register(
     "Instant messaging" : "Instant Messaging",
     "Phone" : "Telefon",
     "Mobile" : "Mobil",
+    "Work mobile" : "Mobil Arbeit",
     "Fax" : "Fax",
     "Fax home" : "Fax privat",
-    "Fax work" : "Fax geschäftlich",
+    "Fax work" : "Fax Arbeit",
     "Pager" : "Pager",
     "Voice" : "Anruf",
+    "Car" : "Auto",
+    "Work pager" : "Pager Arbeit",
     "Social network" : "Soziales Netzwerk",
     "Relationship" : "Beziehung",
-    "Spouse" : "Ehepartner",
+    "Spouse" : "Partner",
     "Child" : "Kind",
     "Mother" : "Mutter",
     "Father" : "Vater",
