@@ -11,19 +11,29 @@ OC.L10N.register(
     "Share with users or groups" : "Διαμοιρασμός με χρήστες ή ομάδες",
     "can edit" : "με δυνατότητα επεξεργασίας",
     "Close" : "Κλείσιμο",
+    "Enabled" : "Ενεργοποιημένο",
+    "Disabled" : "Απενεργοποιημένο",
     "Copied!" : "Αντιγράφτηκε!",
     "Not supported!" : "Δεν υποστηρίζεται!",
     "Press ⌘-C to copy." : "Για αντιγραφή πατήστε ⌘-C.",
     "Press Ctrl-C to copy." : "Για αντιγραφή πατήστε Ctrl-C.",
     "Address book name" : "Όνομα βιβλίου διευθύνσεων",
+    "Only these special characters are allowed: -_.!?#|()" : "Επιτρέπονται μόνο αυτοί οι ειδικοί χαρακτήρες: -_.!?#|()",
+    "Address book could not be created." : "Το βιβλίο διευθύνσεων δεν μπορεί να δημιουργηθεί.",
     "The selected image is too big (max 1MB)" : "Η επιλεγμένη εικόνα είναι πολύ μεγάλη (Μεγ. 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Αυτή η κάρτα είναι κατεστραμμένη και έχει διορθωθεί. Παρακαλώ ελέγξτε τα δεδομένα και αποθηκεύσετε τα ώστε οι αλλαγές να γίνουν μόνιμες.",
     "No contacts in here" : "Δεν υπάρχουν επαφές εδώ",
     "Name" : "Όνομα",
     "Organization" : "Οργανισμός",
     "Title" : "Τίτλος",
+    "Add field …" : "Προσθήκη πεδίου...",
     "Save changes" : "Αποθήκευση αλλαγών",
     "Address book" : "Βιβλίο διευθύνσεων",
+    "Loading contacts …" : "Φόρτωση επαφών ...",
+    "Import into" : "Εισαγωγή σε",
+    "Importing..." : "Γίνεται εισαγωγή...",
+    "Select your addressbook" : "Επιλογή βιβλίου διευθύνσεων",
+    "Import is disabled because no writable address book had been found." : "Η λειτουργία εισαγωγής απενεργοποιήθηκε, καθώς δεν βρέθηκε κάποιο βιβλίο διευθύνσεων με δικαιώματα εγγραφής.",
     "No search result for {query}" : "Δεν βρέθηκε αποτέλεσμα αναζήτησης για {query}",
     "All contacts" : "Όλες οι επαφές",
     "Post office box" : "Ταχυδρομική θυρίδα",
@@ -38,14 +48,21 @@ OC.L10N.register(
     "Additional names" : "Επιπλέον ονόματα",
     "Prefix" : "Πρόθεμα",
     "Suffix" : "Κατάληξη",
+    "Importing into" : "Εισαγωγή σε",
     "New contact" : "Νέα επαφή",
     "Not grouped" : "Οχι ομαδοποιημένα",
     "Sort by" : "Ταξινόμηση κατά",
+    "There is no address book available to create a contact." : "Δεν υπάρχει βιβλίο διευθύνσεων διαθέσιμο για την δημιουργία της επαφής.",
     "{addressbook} shared by {owner}" : "Το {addressbook} διαμοιράστηκε από τον/την {owner}",
+    "Contact not found." : "Δεν βρέθηκε η επαφή.",
+    "You don't have permission to write to this addressbook." : "Δεν έχετε δικαίωμα εγγραφής σε αυτό το βιβλίο διευθύνσεων.",
     "Contact could not be created." : "Αδυναμία δημιουργίας επαφής.",
     "No contacts in file. Only vCard files are allowed." : "Δεν υπάρχουν επαφές στο αρχείο. Μόνο vCard αρχεία επιτρέπονται.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Υποστηρίζεται μόνο η VCard έκδοση 4.0 (RFC6350) ή έκδοση 3.0 (RFC2426).",
+    "Contact could not be moved." : "Η επαφή δεν μπορεί να μετακινηθεί.",
     "Contact could not be saved." : "Αδυναμία αποθήκευσης επαφής.",
+    "Waiting for the server to be ready…" : "Αναμονή για προετοιμασία του διακομιστή...",
+    "Importing…" : "Γίνεται εισαγωγή...",
     "Display name" : "Εμφανιζόμενο όνομα",
     "Nickname" : "Παρατσούκλι",
     "Detailed name" : "Λεπτομερές όνομα",
@@ -63,12 +80,31 @@ OC.L10N.register(
     "Instant messaging" : "Άμεσα μηνύματα",
     "Phone" : "Τηλέφωνο",
     "Mobile" : "Κινητό",
+    "Work mobile" : "Κινητό εργασίας",
     "Fax" : "Φαξ",
     "Fax home" : "Φαξ σπίτι",
     "Fax work" : "Φαξ εργασία",
     "Pager" : "Βομβητής",
     "Voice" : "Ομιλία",
+    "Car" : "Αμάξι",
+    "Work pager" : "Βομβητής δουλειάς",
     "Social network" : "Κοινωνικό δίκτυο",
+    "Relationship" : "Σχέση",
+    "Spouse" : "Σύζηγος",
+    "Child" : "Παιδί",
+    "Mother" : "Μητέρα",
+    "Father" : "Πατέρας",
+    "Parent" : "Γονέας",
+    "Brother" : "Αδελφός",
+    "Sister" : "Αδελφή",
+    "Relative" : "Συγγενής",
+    "Friend" : "Φίλος",
+    "Colleague" : "Συνάδελφος",
+    "Manager" : "Διευθυντής",
+    "Assistant" : "Βοηθός",
+    "Gender" : "Φύλλο",
+    "Female" : "Θηλυκό",
+    "Male" : "Αρσενικό",
     "Details" : "Λεπτομέριες",
     "Settings" : "Ρυθμίσεις"
 },
