@@ -11,6 +11,8 @@ OC.L10N.register(
     "Share with users or groups" : "Share with users or groups",
     "can edit" : "can edit",
     "Close" : "Close",
+    "Enabled" : "Enabled",
+    "Disabled" : "Disabled",
     "Copied!" : "Copied!",
     "Not supported!" : "Not supported!",
     "Press ⌘-C to copy." : "Press ⌘-C to copy.",
@@ -31,6 +33,7 @@ OC.L10N.register(
     "Import into" : "Import into",
     "Importing..." : "Importing...",
     "Select your addressbook" : "Select your addressbook",
+    "Import is disabled because no writable address book had been found." : "Import is disabled because no writable address book had been found.",
     "No search result for {query}" : "No search result for {query}",
     "All contacts" : "All contacts",
     "Post office box" : "Post office box",
@@ -49,14 +52,17 @@ OC.L10N.register(
     "New contact" : "New contact",
     "Not grouped" : "Not grouped",
     "Sort by" : "Sort by",
+    "There is no address book available to create a contact." : "There is no address book available to create a contact.",
     "{addressbook} shared by {owner}" : "{addressbook} shared by {owner}",
     "Contact not found." : "Contact not found.",
     "You don't have permission to write to this addressbook." : "You don't have permission to write to this addressbook.",
     "Contact could not be created." : "Contact could not be created.",
     "No contacts in file. Only vCard files are allowed." : "No contacts in file. Only vCard files are allowed.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported.",
+    "Contact could not be moved." : "Contact could not be moved.",
     "Contact could not be saved." : "Contact could not be saved.",
-    "Waiting for the server to be ready..." : "Waiting for the server to be ready...",
+    "Waiting for the server to be ready…" : "Waiting for the server to be ready…",
+    "Importing…" : "Importing…",
     "Display name" : "Display name",
     "Nickname" : "Nickname",
     "Detailed name" : "Detailed name",
@@ -74,11 +80,14 @@ OC.L10N.register(
     "Instant messaging" : "Instant messaging",
     "Phone" : "Phone",
     "Mobile" : "Mobile",
+    "Work mobile" : "Work mobile",
     "Fax" : "Fax",
     "Fax home" : "Fax home",
     "Fax work" : "Fax work",
     "Pager" : "Pager",
     "Voice" : "Voice",
+    "Car" : "Car",
+    "Work pager" : "Work pager",
     "Social network" : "Social network",
     "Relationship" : "Relationship",
     "Spouse" : "Spouse",
