@@ -11,22 +11,29 @@ OC.L10N.register(
     "Share with users or groups" : "Jaga kasutajate või gruppidega",
     "can edit" : "Võib redigeerida",
     "Close" : "Sulge",
+    "Enabled" : "Lubatud",
+    "Disabled" : "Keelatud",
     "Copied!" : "Kopeeritud!",
     "Not supported!" : "Pole toetatud!",
     "Press ⌘-C to copy." : "Kopeerimiseks vajuta ⌘ + C.",
     "Press Ctrl-C to copy." : "Kopeerimiseks vajuta Ctrl + C.",
     "Address book name" : "Aadressiraamatu nimi",
+    "Only these special characters are allowed: -_.!?#|()" : "Lubatud on ainult järgnevad erimärgid: -_.!?#|()",
+    "Address book could not be created." : "Aadressiraamatu loomine ebaõnnestus.",
     "The selected image is too big (max 1MB)" : "Valitud pilt on liiga suur (maks 1MB)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "See kaart on rikutud ja on fikseeritud. Palun kontrollige andmeid ja käivitage salvestis, et muuta muudatused püsivaks.",
     "No contacts in here" : "Ühtegi kontakti pole",
     "Name" : "Nimi",
     "Organization" : "Organisatsioon",
     "Title" : "Pealkiri",
+    "Add field …" : "Lisa väli ...",
     "Save changes" : "Salvesta muudatused",
     "Address book" : "Aadressiraamat",
+    "Loading contacts …" : "Laen kontakte ...",
     "Import into" : "import sisse",
     "Importing..." : "importimine...",
     "Select your addressbook" : "Valige oma aadressiraamat",
+    "Import is disabled because no writable address book had been found." : "Importimine on keelatud, kuna ühtegi kirjutusõigusega aadressiraamatut ei leitud.",
     "No search result for {query}" : "Otsingutulemused sõnadele {query}",
     "All contacts" : "Kõik kontaktid",
     "Post office box" : "Postkast",
@@ -45,20 +52,23 @@ OC.L10N.register(
     "New contact" : "Uus kontakt",
     "Not grouped" : "Pole grupeeritud",
     "Sort by" : "Sorteeri",
+    "There is no address book available to create a contact." : "Kontakti loomiseks pole ühtegi aadressiraamatut saadaval.",
     "{addressbook} shared by {owner}" : "{owner} jagas aadressiraamatut {addressbook}",
     "Contact not found." : "Kontakte ei leitud",
-    "You don't have permission to write to this addressbook." : "Sul puudub selles aadressiraamatus kirjutamisõigus.",
+    "You don't have permission to write to this addressbook." : "Sul puuduvad õigused käesolevasse aadressiraamatuse kirjutamiseks.",
     "Contact could not be created." : "Kontakti loomine ebaõnnestus.",
     "No contacts in file. Only vCard files are allowed." : "Failis pole kontakte. Lubatud on ainult VCard.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Ainult vCard versioon 4.0 (RFC6350) või versioon 3.0 (RFC2426) on toetatud.",
+    "Contact could not be moved." : "Kontakti liigutamine ebaõnnestus.",
     "Contact could not be saved." : "Kontakti loomine ebaõnnestus.",
-    "Waiting for the server to be ready..." : "Ootab serveri valmisolekut...",
+    "Waiting for the server to be ready…" : "Server on kohe valmis...",
+    "Importing…" : "Impordin...",
     "Display name" : "Kuva nimi",
     "Nickname" : "Hüüdnimi",
     "Detailed name" : "Üksikasjalik nimi",
     "Notes" : "Märkmed",
     "Website" : "Veebileht",
-    "Federated Cloud ID" : "Liitunud pilve ID",
+    "Federated Cloud ID" : "Liitpilve ID",
     "Home" : "Kodu",
     "Work" : "Töö",
     "Other" : "Muu",
@@ -67,14 +77,17 @@ OC.L10N.register(
     "Anniversary" : "Aastapäev",
     "Date of death" : "Surma kuupäev",
     "Email" : "E-post",
-    "Instant messaging" : "Kiirõnumid",
+    "Instant messaging" : "Kiirsõnumid",
     "Phone" : "Telefon",
     "Mobile" : "Mobiil",
+    "Work mobile" : "Töötelefon (mobiil)",
     "Fax" : "Faks",
     "Fax home" : "Faks kodus",
     "Fax work" : "Faks tööl",
     "Pager" : "Piipar",
     "Voice" : "Hääl",
+    "Car" : "Auto",
+    "Work pager" : "Piipar (tööl)",
     "Social network" : "Sotsiaalvõrk",
     "Relationship" : "Suhe",
     "Spouse" : "Abikaasa",
