@@ -11,13 +11,15 @@ OC.L10N.register(
     "Share with users or groups" : "Partager avec des utilisateurs ou des groupes",
     "can edit" : "peut modifier",
     "Close" : "Fermer",
+    "Enabled" : "Activé",
+    "Disabled" : "Désactivé",
     "Copied!" : "Copié !",
     "Not supported!" : "Non pris en charge !",
     "Press ⌘-C to copy." : "Appuyez sur ⌘-C pour copier.",
     "Press Ctrl-C to copy." : "Appuyez sur Ctrl-C pour copier.",
     "Address book name" : "Nom du carnet d'adresses",
-    "Only these special characters are allowed: -_.!?#|()" : "Uniquement ces caractères spéciaux sont autorisés : -_.!?#|()",
-    "Address book could not be created." : "Impossible de créer le carnet d'adresse.",
+    "Only these special characters are allowed: -_.!?#|()" : "Seuls ces caractères spéciaux sont autorisés : -_.!?#|()",
+    "Address book could not be created." : "Impossible de créer le carnet d'adresses.",
     "The selected image is too big (max 1MB)" : "L'image sélectionnée est trop volumineuse (1 Mo max)",
     "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Cette carte est corrompue et a été corrigée. Veuillez vérifier les données et lancer une sauvegarde pour rendre les changements définitifs.",
     "No contacts in here" : "Aucun contact",
@@ -29,8 +31,9 @@ OC.L10N.register(
     "Address book" : "Carnet d'adresses",
     "Loading contacts …" : "Chargement des contacts...",
     "Import into" : "Importer vers",
-    "Importing..." : "Import en cours",
-    "Select your addressbook" : "Sélectionner votre carnet d'adresse",
+    "Importing..." : "Importation en cours",
+    "Select your addressbook" : "Sélectionner votre carnet d'adresses",
+    "Import is disabled because no writable address book had been found." : "L'importation est désactivé car aucun carnet d'adresses modifiable n'a été trouvé.",
     "No search result for {query}" : "Aucun résultat pour {query}",
     "All contacts" : "Tous les contacts",
     "Post office box" : "Boîte postale",
@@ -45,18 +48,21 @@ OC.L10N.register(
     "Additional names" : "Noms supplémentaires",
     "Prefix" : "Préfixe",
     "Suffix" : "Suffixe",
-    "Importing into" : "Import vers",
+    "Importing into" : "Importer dans",
     "New contact" : "Nouveau contact",
     "Not grouped" : "Non groupés",
     "Sort by" : "Trier par",
+    "There is no address book available to create a contact." : "Il n'y a aucun carnet d'adresses disponible pour créer un contact.",
     "{addressbook} shared by {owner}" : "{addressbook} partagé par {owner}",
     "Contact not found." : "Contact introuvable.",
-    "You don't have permission to write to this addressbook." : "Vous n'avez pas les droits suffisants pour écrire dans le carnet d'adresse.",
+    "You don't have permission to write to this addressbook." : "Vous n'avez pas la permission d'écrire dans ce carnet d'adresses.",
     "Contact could not be created." : "Ce contact n'a pu être créé.",
     "No contacts in file. Only vCard files are allowed." : "Aucun contact dans le fichier. Seuls les fichiers vCard sont autorisés.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Seules les vCard version 4.0 (RFC6350) ou version 3.0 (RFC2426) sont supportées.",
+    "Contact could not be moved." : "Ce contact n'a pas pu être déplacé.",
     "Contact could not be saved." : "Ce contact n'a pu être enregistré.",
-    "Waiting for the server to be ready..." : "En attente d'une réponse du serveur",
+    "Waiting for the server to be ready…" : "En attente d'une réponse du serveur...",
+    "Importing…" : "Importation en cours...",
     "Display name" : "Nom affiché",
     "Nickname" : "Surnom",
     "Detailed name" : "Nom complet",
@@ -74,11 +80,14 @@ OC.L10N.register(
     "Instant messaging" : "Messagerie instantanée",
     "Phone" : "Téléphone",
     "Mobile" : "Mobile",
+    "Work mobile" : "Téléphone portable professionnel",
     "Fax" : "Fax",
     "Fax home" : "Fax personnel",
     "Fax work" : "Fax pro",
     "Pager" : "Bipeur",
     "Voice" : "Voix",
+    "Car" : "Voiture",
+    "Work pager" : "Bip professionnel",
     "Social network" : "Réseau social",
     "Relationship" : "Relation",
     "Spouse" : "Conjoint",
