@@ -11,6 +11,8 @@ OC.L10N.register(
     "Share with users or groups" : "ユーザーまたはグループと共有する",
     "can edit" : "編集を許可",
     "Close" : "閉じる",
+    "Enabled" : "有効",
+    "Disabled" : "無効",
     "Copied!" : "コピーしました！",
     "Not supported!" : "サポートされていません！",
     "Press ⌘-C to copy." : "⌘-Cを押してコピーします。",
@@ -31,6 +33,7 @@ OC.L10N.register(
     "Import into" : "インポート",
     "Importing..." : "インポート中...",
     "Select your addressbook" : "あなたのアドレス帳を選択してください",
+    "Import is disabled because no writable address book had been found." : "書き込み可能なアドレス帳が見つからないため，インポートできません",
     "No search result for {query}" : "{query} に関する検索結果はありません。",
     "All contacts" : "すべての連絡先",
     "Post office box" : "私書箱",
@@ -49,11 +52,14 @@ OC.L10N.register(
     "New contact" : "新しい連絡先",
     "Not grouped" : "グループ化されていません",
     "Sort by" : "ソート",
+    "There is no address book available to create a contact." : "連絡先を作成するためのアドレス帳がありません",
     "{addressbook} shared by {owner}" : " {owner}と共有中の{addressbook} ",
     "Contact not found." : "連絡先がありません",
+    "You don't have permission to write to this addressbook." : "アドレス帳への書き込み権限がありません",
     "Contact could not be created." : "連絡先を作成できませんでした。",
     "No contacts in file. Only vCard files are allowed." : "ファイルに連絡先がありません。vCardファイルのみ有効です",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "vCard のバージョンは、4.0 (RFC6350) または、3.0 (RFC2426) をサポートしています。",
+    "Contact could not be moved." : "連絡先を移動できませんでした",
     "Contact could not be saved." : "連絡先を保存できませんでした。",
     "Waiting for the server to be ready…" : "サーバー状況確認中",
     "Importing…" : "読み込み中...",
@@ -80,6 +86,7 @@ OC.L10N.register(
     "Fax work" : "職場FAX",
     "Pager" : "ポケベル",
     "Voice" : "音声番号",
+    "Car" : "自動車",
     "Social network" : "ソーシャルネットワーク",
     "Child" : "子供",
     "Mother" : "母親",
