@@ -47,12 +47,10 @@ OC.L10N.register(
     "Sort by" : "Rikiuoti pagal",
     "{addressbook} shared by {owner}" : "{owner} pradėjo bendrinti {addressbook}",
     "Contact not found." : "Kontaktinis asmuo nerastas.",
-    "You don't have permission to write to this addressbook." : "Jūs neturite leidimo rašyti į šią adresų knygelę.",
     "Contact could not be created." : "Nepavyko sukurti adresato.",
     "No contacts in file. Only vCard files are allowed." : "Byloje nėra adresatų duomenų. Tik vCard tipo bylos palaikomos.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Palaikomos vCard 4.0 versija (RFC6350) ir vCard 3.0 versija (RFC2426).",
     "Contact could not be saved." : "Nepavyko įrašyti adresato.",
-    "Waiting for the server to be ready..." : "Laukiama kol serveris bus pasiruošęs...",
     "Display name" : "Rodomas vardas",
     "Nickname" : "Slapyvardis",
     "Detailed name" : "Pilnas vardas",
