@@ -33,6 +33,7 @@ OC.L10N.register(
     "Import into" : "Importovať do",
     "Importing..." : "Importujem...",
     "Select your addressbook" : "Vyberte svoj adresár",
+    "Import is disabled because no writable address book had been found." : "Import je zakázaný, pretože nebol nájdený žiaden zapisovateľný adresár kontaktov.",
     "No search result for {query}" : "Žiadne výsledky vyhľadávania pre {query}",
     "All contacts" : "Všetky kontakty",
     "Post office box" : "Poštová adresa",
@@ -51,6 +52,7 @@ OC.L10N.register(
     "New contact" : "Nový kontakt",
     "Not grouped" : "Bez skupiny",
     "Sort by" : "Zoradiť podľa",
+    "There is no address book available to create a contact." : "Na vytvorenie kontaktu nie je k dispozícii žiadny adresár kontaktov.",
     "{addressbook} shared by {owner}" : "{addressbook} sprístupňuje {owner}",
     "Contact not found." : "Kontakt sa nenašiel",
     "You don't have permission to write to this addressbook." : "Pre zápis do tohto adresára nemáte oprávnenia.",
