@@ -3,22 +3,29 @@ OC.L10N.register(
     {
     "Contacts" : "Stiki",
     "Download" : "Prejmi",
-    "ShowURL" : "Prikaži URL",
-    "Share Addressbook" : "Deli Imenik",
-    "Delete Addressbook" : "Pobriši Imenik",
-    "Share with users or groups" : "Deli z uporabniki ali skupinami",
+    "Copy link" : "Kopiraj povezavo",
+    "Click to copy the link to your clipboard" : "Klikni, da kopiraš povezavo na tvoje odlagališče",
+    "Toggle sharing" : "Preklopi deljenje",
     "Delete" : "Pobriši",
+    "Rename" : "Preimenuj",
+    "Share with users or groups" : "Deli z uporabniki ali skupinami",
     "can edit" : "lahko ureja",
+    "Close" : "Zapri",
+    "Copied!" : "Kopirano!",
+    "Not supported!" : "Ni podprto!",
+    "Press ⌘-C to copy." : "Pritisni ⌘-C za kopiranje.",
+    "Press Ctrl-C to copy." : "Pritisni Ctrl-C za kopiranje.",
     "Address book name" : "Ime imenika",
-    "Import" : "Uvozi",
     "The selected image is too big (max 1MB)" : "Izbrana slika je prevelika (omejitev je 1 MB).",
+    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Ta kartica je počkodovana in je bila popravljena. Preveri podatke in shrani, da bodo spremembe trajne.",
     "No contacts in here" : "Ni dodanega nobenega stika!",
     "Name" : "Ime",
     "Organization" : "Ustanova",
-    "Title" : "Naslov",
-    "Add field ..." : "Dodaj polje ...",
+    "Title" : "Naziv/funkcija",
+    "Save changes" : "Shrani spremembe",
+    "Address book" : "Imenik",
     "No search result for {query}" : "Ni zadetkov iskanja za {query}",
-    "_%n contact_::_%n contacts_" : ["%n stik","%n stika","%n stiki","%n stikov"],
+    "All contacts" : "Vsi stiki",
     "Post office box" : "Poštni predal",
     "Postal code" : "Poštna številka",
     "City" : "Mesto",
@@ -31,16 +38,19 @@ OC.L10N.register(
     "Additional names" : "Druga imena",
     "Prefix" : "Predpona",
     "Suffix" : "Pripona",
-    "All contacts" : "Vsi stiki",
-    "Not grouped" : "Brez skupine",
     "New contact" : "Nov stik",
+    "Not grouped" : "Brez skupine",
+    "Sort by" : "Uredi po",
     "{addressbook} shared by {owner}" : "Souporabo imenika {addressbook} je omogočil uporabnik {owner}",
+    "Contact not found." : "Stika ne najdem.",
     "Contact could not be created." : "Stika ni mogoče ustvariti.",
-    "No contacts in file. Only VCard files are allowed." : "V datoteki ni vpisanih stikov. Dovoljeni so le vpisi datotek VCard.",
-    "Only VCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Samo VCard verziji 4.0 (RFC6350) ali verzija 3.0 (RFC2426) sta podprti.",
+    "No contacts in file. Only vCard files are allowed." : "V datoteki ni stikov. Dovoljene so samo vCard datoteke.",
+    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Podpiramo samo vCard verzije 4.0 (RFC6350) ali verzije 3.0 (RFC2426).",
+    "Contact could not be saved." : "Stikov ne morem shraniti.",
+    "Display name" : "Prikaži ime",
     "Nickname" : "Vzdevek",
     "Detailed name" : "Podrobno ime",
-    "Notes" : "Sporočilca",
+    "Notes" : "Zapiski",
     "Website" : "Spletna stran",
     "Federated Cloud ID" : "ID zveznega oblaka",
     "Home" : "Domači naslov",
@@ -60,6 +70,7 @@ OC.L10N.register(
     "Pager" : "Pozivnik",
     "Voice" : "Glas",
     "Social network" : "Družbeno omrežje",
+    "Details" : "Podrobnosti",
     "Settings" : "Nastavitve"
 },
 "nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
