@@ -11,6 +11,8 @@ OC.L10N.register(
     "Share with users or groups" : "Kullanıcı ve gruplarla paylaş",
     "can edit" : "düzenleyebilir",
     "Close" : "Kapat",
+    "Enabled" : "Etkin",
+    "Disabled" : "Devre Dışı",
     "Copied!" : "Kopyalandı!",
     "Not supported!" : "Desteklenmiyor!",
     "Press ⌘-C to copy." : "Kopyalamak için ⌘-C tuşlarına basın.",
@@ -31,6 +33,7 @@ OC.L10N.register(
     "Import into" : "Şunun içine aktar",
     "Importing..." : "İçe aktarılıyor...",
     "Select your addressbook" : "Adres defterinizi seçin",
+    "Import is disabled because no writable address book had been found." : "Yazılabilecek bir adres defteri bulunamadığından içe aktarım devre dışı bırakıldı.",
     "No search result for {query}" : "{query} aramasından bir sonuç alınamadı",
     "All contacts" : "Tüm kişiler",
     "Post office box" : "Posta kutusu",
@@ -49,14 +52,17 @@ OC.L10N.register(
     "New contact" : "Yeni kişi",
     "Not grouped" : "Gruplanmamış",
     "Sort by" : "Sıralama",
+    "There is no address book available to create a contact." : "Kişi kaydının eklenebileceği bir adres defteri yok.",
     "{addressbook} shared by {owner}" : "{owner} tarafından paylaşılmış {addressbook}",
     "Contact not found." : "Kişi bulunamadı.",
     "You don't have permission to write to this addressbook." : "Bu adres defterine yazma izniniz yok.",
     "Contact could not be created." : "Kişi oluşturulamadı.",
     "No contacts in file. Only vCard files are allowed." : "Dosyada herhangi bir kişi yok. Yalnız vCard dosyaları kullanılabilir.",
     "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Yalnız vCard sürüm 4.0 (RFC6350) ya da sürüm 3.0 (RFC2426) desteklenir.",
+    "Contact could not be moved." : "Kişi taşınamadı.",
     "Contact could not be saved." : "Kişi kaydedilemedi.",
-    "Waiting for the server to be ready..." : "Sunucunun hazır olması bekleniyor...",
+    "Waiting for the server to be ready…" : "Sunucunun hazır olması bekleniyor…",
+    "Importing…" : "İçe aktarılıyor…",
     "Display name" : "Görüntülenecek ad",
     "Nickname" : "Kısaltma",
     "Detailed name" : "Ayrıntılı ad",
@@ -74,11 +80,14 @@ OC.L10N.register(
     "Instant messaging" : "Anlık iletişim",
     "Phone" : "Telefon",
     "Mobile" : "Cep telefonu",
+    "Work mobile" : "İş cep telefonu",
     "Fax" : "Faks",
     "Fax home" : "Ev faksı",
     "Fax work" : "İş faksı",
     "Pager" : "Çağrı cihazı",
     "Voice" : "Ses",
+    "Car" : "Araç telefonu",
+    "Work pager" : "İş çağrı cihazı",
     "Social network" : "Sosyal ağ",
     "Relationship" : "İlişki",
     "Spouse" : "Eş",
